package com.fs.oms.service;

import java.util.List;
import com.fs.oms.domain.OmsPurchaseApply;
import com.fs.oms.vo.OmsPurchaseApplyStatusVO;
import com.fs.oms.vo.OmsPurchaseApplyVO;
import com.fs.oms.vo.OmsPurchaseProductVO;

/**
 * 采购申请单Service接口
 *
 * @author fs
 * @date 2023-06-20
 */
public interface IOmsPurchaseApplyService
{
    /**
     * 查询采购申请单
     *
     * @param id 采购申请单ID
     * @return 采购申请单
     */
    public OmsPurchaseApply selectOmsPurchaseApplyById(Long id);

    /**
     * 查询采购申请单列表
     *
     * @param omsPurchaseApply 采购申请单
     * @return 采购申请单集合
     */
    public List<OmsPurchaseApplyVO> selectOmsPurchaseApplyList(OmsPurchaseApply omsPurchaseApply);

    /**
     * 新增采购申请单
     *
     * @param omsPurchaseApply 采购申请单
     * @return 结果
     */
    public int insertOmsPurchaseApply(OmsPurchaseApply omsPurchaseApply);

    /**
     * 修改采购申请单
     *
     * @param omsPurchaseApply 采购申请单
     * @return 结果
     */
    public int updateOmsPurchaseApply(OmsPurchaseApply omsPurchaseApply);

    /**
     * 批量删除采购申请单
     *
     * @param ids 需要删除的采购申请单ID
     * @return 结果
     */
    public int deleteOmsPurchaseApplyByIds(Long[] ids);

    /**
     * 删除采购申请单信息
     *
     * @param id 采购申请单ID
     * @return 结果
     */
    public int deleteOmsPurchaseApplyById(Long id);

    List<OmsPurchaseProductVO> selectOmsPurchaseProductList(OmsPurchaseProductVO omsPurchaseProductVO);

    List<OmsPurchaseProductVO> selectOmsPurchaseProductById(Long id);

    int updateApplyStatus(OmsPurchaseApplyStatusVO omsPurchaseApplyStatusVO);
}
